########
Modules
########

..
    to document functions, add them to __all__ in ../l2awinddirection/__init__.py

.. automodule:: l2awinddirection
    :members:


.. automodule:: l2awinddirection.utils
    :members: 

.. automodule:: l2awinddirection.generate_L2A_winddir_pdf_product
     :members:
